pub struct TextureId(/* private fields */);Expand description
Globally unique 32-bit id, guaranteed via atomics on a static global.
Note that this means the id space is process-wide, as such it may potentially be exhausted
by a combination of long-running processes and multiple bevy Worlds, at which point we panic.
Implementations